<?php

namespace HS\Domain\Documents\VirusScan;

use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Http;
use Illuminate\Http\Client\ConnectionException;

class Opswat
{
    /**
     * @var string
     */
    protected $apiKey;

    /**
     * @param $apiKey
     */
    public function __construct($apiKey)
    {
        $this->apiKey = $apiKey;
    }

    /**
     * @link https://docs.opswat.com/mdcloud/metadefender-cloud-api-v4/ref
     * @link https://docs.opswat.com/mdcloud/metadefender-cloud-api-v4/ref#hash-lookup
     * @param $md5
     * @return ScanResult
     */
    public function scan($md5)
    {
        try {
            $response = Http::timeout(2)
                ->withHeaders(['apikey' => $this->apiKey])
                ->get('https://api.metadefender.com/v4/hash/'.$md5);

            if ($response->status() == 404) {
                return ScanResult::clean();
            }

            if ($response->successful()) {
                return ($this->determineIsClean($response->json()))
                    ? ScanResult::clean()
                    : ScanResult::suspicious();
            } else {
                Log::error(new \Exception('Bad request to opswat'), [
                    'status' => $response->status(),
                    'message' => $response->body(),
                ]);
                // falls down to callback at end of function
            }
        } catch(ConnectionException $e) {
            // Trust, if we get a timeout
            Log::error($e);
            return ScanResult::clean();
        }

        return ScanResult::clean();
    }

    protected function determineIsClean($data)
    {
        if (isset($data['scan_results']['scan_all_result_a'])) {
            return $data['scan_results']['scan_all_result_a'] != 'Infected';
        }

        if(isset($data['process_info']['result'])) {
            return $data['process_info']['result'] != 'Blocked';
        }

        return true;
    }
}
